@@ -69,7 +69,7 @@ union.TidySet <- function(object, sets, name = NULL, FUN = "max", keep = FALSE,
     }
     object <- add_sets(object, name)
     relations <- relations(object)
-    union <- relations[relations$sets %in% sets, ]
+    union <- relations[relations$sets %in% sets, , drop = FALSE]
     if (is.factor(union$sets)) {
         levels(union$sets)[levels(union$sets) %in% sets] <- name
     } else {
@@ -78,7 +78,5 @@ union.TidySet <- function(object, sets, name = NULL, FUN = "max", keep = FALSE,
 
     union <- fapply(union, FUN, ... = ...)
     object <- replace_interactions(object, union, keep_relations)
-    object <- droplevels(object, !keep_elements, !keep_sets, !keep_relations)
-    validObject(object)
-    object
+    droplevels(object, !keep_elements, !keep_sets, !keep_relations)
 }
